#
# spec file for package lftp (Version 3.5.14)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany
# and modifications by Pascal Bleser <guru@unixtech.be>
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%if %suse_version >= 910
%define with_gnutls	1
%else
%define with_openssl	1
%endif

Name:           lftp
Version:        3.6.1
%define vi_version 1.1
Release:        1.1
License:        GNU General Public License version 2 or later (GPL v2 or later)
Group:          Productivity/Networking/Ftp/Clients
URL:            http://lftp.yar.ru/
Summary:        LFTP Command Line File Transfer Program
Source:         http://ftp.yars.free.net/pub/source/lftp/lftp-%{version}.tar.bz2
Source1:        %{name}.desktop
Source2:        http://michael.stapelberg.de/lftp_vi/lftp-vi.%{vi_version}.tar.gz
Patch1:         %{name}-nostrip.patch
Patch2:         %{name}-wrapper.patch
Patch3:         %{name}-compat-mode.patch
Patch4:		    %{name}-autoconf-req.patch
Patch5:		    %{name}-add-cmd-edit-module.patch
Patch6:		    http://michael.stapelberg.de/lftp_vi/lftp-completion.patch
Patch7:		    %{name}-fix-cmd-edit-includes.patch
Patch8:         %{name}-old-autoconf.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ gnutls-devel libstdc++-devel openssl-devel readline-devel update-alternatives
BuildRequires:	 ncurses-devel make autoconf automake libtool update-desktop-files
%if %{?with_gnutls:1}0
BuildRequires:	 gnutls-devel
%endif
%if %{?with_openssl:1}0
BuildRequires:	 openssl-devel
%endif
Obsoletes:	    lftp-beta < %{version}
Conflicts:      ftp
Provides:       nkitb:/usr/bin/ftp
PreReq:         update-alternatives

%description
LFTP is a reliable shell-like command line FTP client. It can retry
operations and does reget automatically. It can do several transfers
simultaneously in the background. With LFTP, you can start a transfer
in the background and continue browsing that FTP site or another one.
This is all done in one process. Background jobs are completed in nohup
mode if you exit or close the modem connection. LFTP has reput, mirror,
and reverse mirror among its features. Since version 2.0, it also
supports the HTTP protocol. Other features include IPV6 support,
context sensitive completion, output redirection to files or to pipe,
FTP and HTTP proxy support, transfer rate throttling for each
connection and for all connections in sum, job queueing, job execution
at specified times, opie and skey support in the FTP protocol, SSL for
HTTP and FTP, and FXP transfers.



Authors:
--------
    Alexander V. Lukyanov <lav@yars.free.net>

%debug_package
%prep
%setup -q 
pushd src
%__tar xzf "%{SOURCE2}"
popd
%patch1
%patch2
%patch3
%patch4
%patch5
pushd src
%patch6
popd #src
%patch7
%if 0%{?suse_version:1} && %suse_version < 1020
%patch8
%endif

%build
%{?suse_update_config:%{suse_update_config}}
libtoolize --force
aclocal -I m4
autoheader
autoconf
touch AUTHORS
automake -a
%if 0%{?suse_version:1} && %suse_version >= 1010
CFLAGS="$CFLAGS -fstack-protector"
%endif
CFLAGS="$CFLAGS" \
CXXFLAGS="$CFLAGS" \
LDFLAGS=' ' \
%configure \
   --with-modules \
%if %{?with_gnutls:1}0
   --with-gnutls --without-openssl \
%endif
%if %{?with_openssl:1}0
   --with-openssl --without-gnutls \
%endif
   --with-modules \
   --with-debug \
   --without-profiling \
   --enable-largefile \
   --with-pager=/usr/bin/less \
   --with-libresolv \
   --without-included-readline

%__make %{?jobs:-j%jobs}

%install
%makeinstall
touch "%{buildroot}%{_bindir}/ftp"
# We don't package the .la files
%__rm -f "%{buildroot}/%{_libdir}"/{lftp/*/,}*.la 

%__install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%__install -D -m 0644 contrib/lftp-icon.png "%{buildroot}%{_datadir}/pixmaps/%{name}.png"
%suse_update_desktop_file -r "%{name}" Network FileTransfer

%find_lang "%{name}"

%post
test -L "%{_bindir}/ftp" || %__rm -f "%{_bindir}/ftp"
update-alternatives --install "%{_bindir}/ftp" ftp "%{_bindir}/lftp_wrapper" 5 \
  --slave "%{_mandir}/man1/ftp.1.gz" ftp.1 "%{_mandir}/man1/lftp.1.gz"
update-alternatives --auto ftp

%preun
if [ $1 -eq 0 ]; then
  update-alternatives --remove ftp "%{_bindir}/lftp_wrapper"
fi

%files -f "lftp.lang"
%defattr(-,root,root)
%doc BUGS COPYING ChangeLog FAQ FEATURES README* NEWS THANKS TODO lftp.lsm
%doc contrib/lftp-icon.png
%config %{_sysconfdir}/lftp.conf
%{_bindir}/lftp
%{_bindir}/lftpget
%{_bindir}/lftp_wrapper
%ghost %{_bindir}/ftp 
%{_datadir}/lftp
%dir %{_libdir}/lftp
%dir %{_libdir}/lftp/%{version}
%{_libdir}/lftp/%{version}/cmd-edit.so
%{_libdir}/lftp/%{version}/cmd-mirror.so
%{_libdir}/lftp/%{version}/cmd-sleep.so
%{_libdir}/lftp/%{version}/compat-mode.so
%{_libdir}/lftp/%{version}/liblftp-getdate.so
%{_libdir}/lftp/%{version}/liblftp-network.so
%{_libdir}/lftp/%{version}/liblftp-pty.so
%{_libdir}/lftp/%{version}/proto-file.so
%{_libdir}/lftp/%{version}/proto-fish.so
%{_libdir}/lftp/%{version}/proto-ftp.so
%{_libdir}/lftp/%{version}/proto-http.so
%{_libdir}/lftp/%{version}/proto-sftp.so
%{_libdir}/liblftp-*.so
%{_libdir}/liblftp-*.so.*
%doc %{_mandir}/man1/lftp.1*
%doc %{_mandir}/man1/lftpget.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%clean
%__rm -rf "%{buildroot}"

%changelog
* Sat Nov  3 2007 guru@unixtech.be
- update to 3.6.0
  highlights from changelist:
  * major code cleanup
  * new setting ftp:use-stat-for-list allows faster directory listing.
  * new command `eval' with -f option allows complex aliases.
  * send encoded parts of ftp URLs untranslated to ftp server.
  * new mirror options --on-change, --depth-first, --no-empty-dirs, --ascii.
  * new mirror option --only-existing (Damon Harper).
  * new setting xfer:log, log successful transfers if true to ~/.lftp/tarnsfer_log.
  * new setting ssl:check-hostname.
  * fixed cls exit code in case of an error.
- ported compat patches to 3.6.0 because of upstream code changes
* Mon Jul 16 2007 mkudlvasr@suse.cz
- update to 3.5.11
  highlights from changelist:
  * fixed mirror for MDTM-less ftp servers.
  * fixed compilation with Sun native compiler
* Thu Apr  5 2007 mkudlvasr@suse.cz
- update to 3.5.10
  highlights from changelist:
  * fixed 'sleep' command
  * fixed 'mirror --script'
* Mon Mar 19 2007 mkudlvasr@suse.cz
- removed RPM_BUILD_ROOT from post-install script
* Tue Oct 17 2006 postadal@suse.cz
- updated to version 3.5.6
  * new settings cmd:parallel and cmd:queue-parallel to set number of jobs
    executed in parallel in non-interactive mode and in a queue.
  * new mirror option --skip-noaccess and setting mirror:skip-noaccess.
  * fixed a coredump when lftp was compiled with a non-gcc compiler.
  * fixed compilation when stdbool.h is missing.
  * fixed a failed assertion.
  * fixed coredump when doing `ls ..' on a http site.
  * fixed memory and file descriptor leak in mget/mput.
* Mon Aug 14 2006 anosek@suse.cz
- updated to version 3.5.4
  * new setting mirror:include-regex.
  * load ssl keys for protected data connection as well; use new option
    ftp:ssl-data-use-keys to disable it.
  * fixed human-readable options of du and cls.
  * fixed compilation on certain systems.
  * fixed a core dump in ftps with gnu tls.
  * fixed random queue duplication.
  * fixed compilation with modules and socks.
  * fixed installation with modules.
  * added configure --enable-packager-mode option
  * new setting mirror:include-regex.
  * load ssl keys for protected data connection as well; use new option
    ftp:ssl-data-use-keys to disable it.
  * fixed human-readable options of du and cls.
  * fixed compilation on certain systems.
* Tue Aug  1 2006 postadal@suse.cz
- updated to version 3.5.2
  * fixed lftp exit code when cmd:at-exit is set
  * new exit options: top, kill
  * new setting dns:max-retries
  * new settings fish:charset and sftp:charset (for sftp version<4)
  * implemented pget -c (continue) with a status file
  * new options of `repeat' command: --count (-c), --delay (-d),
  - -while-ok, --until-ok
  * added support for ALLO command and ftp:use-allo setting
  * changed default for http:use-propfind to no
* Fri Apr 14 2006 pnemec@suse.cz
- decreased priority of alternative system [#162595]
- another fix for lftp wrapper [#164726]
* Fri Apr  7 2006 pnemec@suse.cz
- fixed lftp_wrapper [#162595]
* Mon Mar 20 2006 postadal@suse.cz
- packaged %%ghost /usr/bin/ftp [#159341]
* Mon Mar 13 2006 postadal@suse.cz
- removed lukemftp from Obsoletes [#156450]
* Sat Mar 11 2006 postadal@suse.cz
- added ftp and ftp.1 to alternative system, so they can be
  interchanged with lukemftp [#156450]
* Thu Mar  9 2006 postadal@suse.cz
- fixed update problem (removed lukemftp from Conflicts) [#156450]
* Fri Mar  3 2006 pnemec@suse.cz
- fixed lukemftp update problem 154349
* Fri Jan 27 2006 pnemec@suse.cz
- fixed lftp_wrapper.c [#145143]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 pnemec@suse.cz
- fixed some parts in lftp_wrapper.c
* Tue Jan 17 2006 postadal@suse.cz
- made ftp wrapper and compat-mode module for backward compatibility
  with lukemftp [#52021] (compat-mode.patch, wrapper.patch)
- added -fstack-protector
* Sun Jan 15 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jan  6 2006 postadal@suse.cz
- updated to version 3.4.0
* Wed Nov 23 2005 postadal@suse.cz
- updated to version 3.3.4
- parallelize build
* Thu Jul 28 2005 postadal@suse.cz
- updated to version 3.2.1
- disabled stripping in makefiles to enabling build helpful debuginfo package
- removed obsoleted gcc-sentinel-fix patch
* Wed Jan 19 2005 postadal@suse.cz
- updated to version 3.0.13
- fixed gcc warnings (gcc-sentinel-fix.diff)
* Tue Aug 17 2004 postadal@suse.cz
- removed /usr/bin/ftp link to avoid conflict with other ftp clients [#43765]
* Thu Aug  5 2004 postadal@suse.cz
- updated to version 3.0.6
* Fri Feb 13 2004 postadal@suse.cz
- updated to version 2.6.12
- removed obsoleted patches: http-empty-line-fix, http-overflow-fix
* Tue Feb 10 2004 schwab@suse.de
- Add readline-devel to neededforbuild.
* Tue Dec 16 2003 postadal@suse.cz
- fixed handling first empty line (server's response doesn't parse it correctly)
* Mon Dec  8 2003 postadal@suse.cz
- fixed remote exploitable buffer overflow while using HTTP/HTTPS [#33528]
* Thu Nov  6 2003 schwab@suse.de
- Fix quoting in configure script.
* Thu Sep 18 2003 postadal@suse.cz
- fixed to use stdarg [#30819]
* Wed Aug 20 2003 postadal@suse.cz
- removed forgotten __os_install_post
* Thu Jul 24 2003 postadal@suse.cz
- updated to version 2.6.6
* Mon Jun  2 2003 poeml@suse.de
- run automake
* Wed May 14 2003 mmj@suse.de
- Update to 2.6.5 including:
  * new mirror options --log=<file> and --script=<file> to produce
    lftp commands equivalent to the actions done (log) or to be
    done (script) by mirror. `-' as file name means stdout.
  * fixed a dead-lock when resuming FXP with passive source.
  * re-get file size and date after HTTP redirect.
  * added workarounds for proftpd.
  * handle EPIPE (Broken pipe) error as temporary network error.
  * fixed a dead-lock in HTTP retrieval after redirect.
  * added cls option --sort=date (Oskar Liljeblad).
  * fixed compilation on OpenBSD and older Solaris.
  * fixed handling of symbolic links in find.
  * lftp -f and -c options can now be combined
  * fixed slot handling in non-interactive mode.
  * fixed large file support in cat command.
  * fixed dante socks compilation.
  * fixed data connection abort with ssl connection to wu-ftpd.
- Remove files we don't want to package
* Fri Jan 10 2003 postadal@suse.cz
- updated to version 2.6.4
  * new settings net:socket-bind-ipv4 and net:socket-bind-ipv6 to bind sockets
    to a specific address (to select a specific network interface)
  * reget does not start transfer if not needed
  * ssl:verify-certificate set to no by default
  * fixed ~ handling in find and mirror
* Fri Dec  6 2002 postadal@suse.cz
- new package: lftp 2.6.3
